RarFileChunk

Struct RarFileChunk 

pub struct RarFileChunk {
    pub start_offset: u64,
    pub end_offset: u64,
    /* private fields */
}
Available on crate feature async only.
A byte range within a single FileMedia (RAR volume).

Fields

start_offset: u64end_offset: u64

Implementations

Source

impl RarFileChunk

pub fn new( file_media: Arc<dyn FileMedia>, start_offset: u64, end_offset: u64, ) -> Self

pub fn length(&self) -> u64

Length of this chunk in bytes.

pub fn pad_start(&self, padding: u64) -> Self

Create a new chunk with the start offset moved forward.

pub fn pad_end(&self, padding: u64) -> Self

Create a new chunk with the end offset moved backward.

pub async fn read(&self) -> Result<Vec<u8>>

Read the entire chunk.

pub async fn read_range(&self, start: u64, end: u64) -> Result<Vec<u8>>

Read a portion of the chunk.

pub fn volume_name(&self) -> &str

Get the name of the file media (volume) this chunk belongs to.